<?php


////////////////////////////////////////////////
////// SET PREDEFINED STYLES ///////////////////
////////////////////////////////////////////////

function gg_set_predefined_style() {
	if(!isset($_POST['lcwp_nonce']) || !wp_verify_nonce($_POST['lcwp_nonce'], 'lcwp_nonce')) {die('Cheating?');}
	if(!isset($_POST['style'])) {die('data is missing');}

	require_once(GG_DIR .'/settings/preset_styles.php');

	$style_data = gg_preset_styles_data($_POST['style']);
	if(empty($style_data)) {die('Style not found');}
	
	
	// override values
	foreach($style_data as $key => $val) {
		update_option($key, $val);		
	}


	// if is not forcing inline CSS - create static file
	if(!get_option('mg_inline_css')) {
		gg_create_frontend_css();
	}
	
	die('success');
}
add_action('wp_ajax_gg_set_predefined_style', 'gg_set_predefined_style');




////////////////////////////////////////////////
////// CREATE WATERMARK CACHE //////////////////
////////////////////////////////////////////////

function gg_create_wm_cache() {

	// force PHP debug mode
	ini_set('display_errors', 1);
	ini_set('display_startup_errors', 1);
	error_reporting(E_ALL);	
	
	
	// specific gallery or any gallery?
	$gid = (isset($_POST['gid'])) ? addslashes($_POST['gid']) : false;
	
	if(!$gid) {
		$args = array(
			'post_type' => 'gg_galleries',
			'numberposts' => -1,
			'post_status' => 'publish'
		);
		$galleries = get_posts($args);
	}
	else {
		$galleries = array( get_post($gid));	
	}
	
	
	// perform
	foreach($galleries as $gallery) {
		$gid = $gallery->ID;
		$type = get_post_meta($gid, 'gg_type', true);
		$images = gg_gall_data_get($gid);
	
		if(is_array($images)) {
			foreach($images as $img) { 
				$full_src = gg_img_src_on_type($img['img_src'], $type);
				gg_watermark($full_src);
			}
		}	
	}

	die('success');
}
add_action('wp_ajax_gg_create_wm_cache', 'gg_create_wm_cache');




////////////////////////////////////////////////
////// CLEAN WATERMARK CACHE ///////////////////
////////////////////////////////////////////////

function gg_clean_wm_cache() {
	$wp_dirs = wp_upload_dir();
	$cache_dir = trailingslashit($wp_dirs['basedir']) . 'gg_watermarked';
	
	// folder exists?
	if(!@file_exists($cache_dir)) {
		die('success');	
	}
	
	// clean
	foreach(scandir($cache_dir) as $file) {
		$ext = gg_stringToExt($file);
		$accepted = array('.jpg', '.jpeg', '.gif', '.png');
		
		if(in_array($ext, $accepted) && file_exists($cache_dir.'/'.$file)) {
			unlink($cache_dir.'/'.$file);
		}	
	}

	die('success');
}
add_action('wp_ajax_gg_clean_wm_cache', 'gg_clean_wm_cache');




//////////////////////////////////////////////////////////////////////////////




////////////////////////////////////////////////
////// ADD COLLECTION TERM /////////////////////
////////////////////////////////////////////////

function gg_add_coll() {
	if(!isset($_POST['coll_name'])) {die('missing data');}
	$name = $_POST['coll_name'];
	
	$resp = wp_insert_term( $name, 'gg_collections', array( 'slug'=>sanitize_title($name)) );
	
	if(is_array($resp)) {die('success');}
	else {
		$err_mes = $resp->errors['term_exists'][0];
		die($err_mes);
	}
}
add_action('wp_ajax_gg_add_coll', 'gg_add_coll');



////////////////////////////////////////////////
////// LOAD COLLECTIONS LIST ///////////////////
////////////////////////////////////////////////

function gg_coll_list() {
	if(!isset($_POST['coll_page']) || !filter_var($_POST['coll_page'], FILTER_VALIDATE_INT)) {$pag = 1;}
	$pag = (int)$_POST['coll_page'];
	
	$per_page = 10;
	
	// get all terms 
	$colls = get_terms( 'gg_collections', 'hide_empty=0' );
	$total = count($colls);
	
	$tot_pag = ceil( $total / $per_page );
	
	if($pag > $tot_pag) {$pag = $tot_pag;}
	$offset = ($pag - 1) * $per_page;
	
	// get page terms
	$args =  array(
		'number' => $per_page,
		'offset' => $offset,
		'hide_empty' => 0
	 );
	$colls = get_terms( 'gg_collections', $args);

	// clean term array
	$clean_colls = array();
	
	foreach ( $colls as $coll ) {
		$clean_colls[] = array('id' => $coll->term_id, 'name' => $coll->name);
	}
	
	$to_return = array(
		'colls' => $clean_colls,
		'pag' => $pag, 
		'tot_pag' => $tot_pag
	);
    
	echo json_encode($to_return);
	die();
}
add_action('wp_ajax_gg_get_colls', 'gg_coll_list');




////////////////////////////////////////////////
////// DELETE THE COLLECTION TERM //////////////
////////////////////////////////////////////////

function gg_del_coll() {
	if(!isset($_POST['coll_id'])) {die('missing data');}
	$id = addslashes($_POST['coll_id']);
	
	$resp = wp_delete_term( $id, 'gg_collections');

	if($resp == '1') {die('success');}
	else {die('error during the collection deletion');}
}
add_action('wp_ajax_gg_del_coll', 'gg_del_coll');




////////////////////////////////////////////////
////// DISPLAY COLLECTION BUILDER //////////////
////////////////////////////////////////////////

function gg_coll_builder() {
	if(!isset($_POST['coll_id'])) {die('missing data');}
	$coll_id = addslashes($_POST['coll_id']);
			
	// item categories list
	$item_cats = get_terms( 'gg_gall_categories', 'hide_empty=0' );
	
	// cat and page selector
	?>
    <h2></h2>
    
    <div id="gg_grid_builder_cat" class="postbox" style="min-width: 630px;">
      <h3 class="hndle"><?php _e("Add Collection Galleries", GG_ML); ?></h3>
      <div class="inside">
    
        <div class="lcwp_mainbox_meta">
          <table class="widefat lcwp_table lcwp_metabox_table" style="border: none;">
            <tr>
              <td>
                  <label style="width: 145px;"><?php _e("Gallery Categories", GG_ML); ?></label>
                  
                  <select data-placeholder="<?php _e("Select gallery categories", GG_ML); ?> .." name="gg_gall_cats" id="gg_gall_cats" class="lcweb-chosen" style="width: 314px;" autocomplete="off">
                    <option value="all"><?php _e('Any category', GG_ML) ?></option>
                      
                    <?php 
                    foreach($item_cats as $cat) {
                        // WPML fix - get original ID
                        if (function_exists('icl_object_id') && isset($GLOBALS['sitpress'])) {
                            global $sitepress;
							$term_id = icl_object_id($cat->term_id, 'gg_gall_categories', true, $sitepress->get_default_language());
                        }
                        else {$term_id = $cat->term_id;}
                            
                        echo '<option value="'.$term_id.'">'.$cat->name.'</option>';
                    }
                    ?>
                </select>
              </td>
            </tr>
            <tr>
              <td style="padding-bottom: 0 !important;">
                <div>
                    <label style="width: 145px;"><?php _e("Select galleries", GG_ML); ?></label>
                    <input type="text" name="gg_coll_gall_search" id="gg_coll_gall_search" style="width: 314px; padding-right: 28px;" placeholder="<?php _e('search galleries', GG_ML) ?>" autocomplete="off" />
                    
                    <i class="gg_cgs_mag" title="<?php _e('search', GG_ML) ?>"></i>
                    <i class="gg_cgs_del" title="<?php _e('cancel', GG_ML) ?>"></i>
                    
                    <a href="javascript:void(0)" class="gg_cgs_show_all">(<?php _e('expand', GG_ML) ?>)</a>
                </div>
                
                <ul id="gg_coll_gall_picker">
                    <?php 
                    $post_list = gg_cat_galleries_code('all'); 
                    
                    if(!$post_list) {echo '<span>'. __('No galleries found', GG_ML) .' ..</span>';}
                    else {echo $post_list;}
                    ?>
                </ul>
              </td>
            </tr>
          </table>  
        <div>  
      </div>
	</div>
    </div>
    </div>
    
    <div class="postbox" style="min-width: 630px;">
      <h3 class="hndle"><?php _e("Collection Builder", GG_ML); ?></h3>
      <div class="inside">
      
		<div id="visual_builder_wrap">
        
		<table id="gg_coll_builder">
          <tbody>	
          <?php
          $coll_data = get_term($coll_id, 'gg_collections');
		  $coll_composition = unserialize($coll_data->description);
		  $coll_galleries = $coll_composition['galleries'];
		  
          if(is_array( $coll_galleries) && count( $coll_galleries) > 0) {
			
			$a = 0;  
            foreach( $coll_galleries as $gdata) {
			  $gid = $gdata['id'];
			  $gall_img = gg_get_gall_first_img($gid);	
				
			  if(get_post_status($gid) == 'publish' && $gall_img) {

				  $rand_check 	= (isset($gdata['rand']) && $gdata['rand'] != 0) ? 'checked="checked"' : '';
				  $wmark_check 	= (isset($gdata['wmark']) && $gdata['wmark'] != 0) ? 'checked="checked"' : '';  
				  $filter_check	= (isset($gdata['filters']) && $gdata['filters'] != 0) ? 'checked="checked"' : ''; 
				  $search_check	= (isset($gdata['search']) && $gdata['search'] != 0) ? 'checked="checked"' : ''; 	
					
				  $link_subj 	= (isset($gdata['link_subj'])) ? $gdata['link_subj'] : 'none'; 
				  $link_val 	= (isset($gdata['link_val'])) ? $gdata['link_val'] : '';
				  $descr 		= (isset($gdata['descr'])) ? $gdata['descr'] : ''; 
				  
				  // custom image
				  if(isset($gdata['cust_img']) && $gdata['cust_img']) {
					$cust_img = gg_thumb_src($gdata['cust_img'], 500, 500, 70);
					$cust_img_id = $gdata['cust_img'];
					$ci_icon_sel_class = 'gg_coll_cust_img_sel';   
				  } 
				  else {
					$cust_img = '';
					$cust_img_id = '';
					$ci_icon_sel_class = '';  
				  }
				 
				  $orig_thumb = gg_thumb_src($gall_img, 500, 500, 70);
				  $thumb_to_use = (empty($cust_img)) ? $orig_thumb : $cust_img;
				  
				  
				  // categories
				  $gall_cats = gg_gallery_cats($gid, 'list', ', ');
				  $gall_cats = (empty($gall_cats)) ? '<em>'. __('No associated categories', GG_ML) .' ..</em>' : '<em class="dashicons dashicons-tag" title="'. esc_attr(__('Categories', GG_ML)) .'" style="padding-right: 3px; font-size: 16px; line-height: 23px;"></em> '.$gall_cats;

				  echo '
				  <tr class="coll_component" id="gg_coll_'.$gid.'">
					<td class="gg_coll_gall_imgbox" style="width: 230px; vertical-align: top; background-image: url('. $thumb_to_use .');">
						
						<div class="lcwp_del_row gg_del_gall"></div>
						<div class="lcwp_move_row"></div>
						
						<div class="gg_coll_cust_img_btn '. $ci_icon_sel_class .'" title="'. esc_attr(__('Manage custom main image', GG_ML)) .'">
							<i class="fa fa-camera" aria-hidden="true"></i>
							<input type="hidden" name="gg_coll_cust_img" value="'. $cust_img_id .'" class="gg_coll_cust_img" />
							
							<div class="gg_coll_del_cust_img_btn" title="'. esc_attr(__('Remove custom main image', GG_ML)) .'" orig-img="'. $orig_thumb .'">
								<i class="fa fa-camera" aria-hidden="true"></i>
							</div>
						</div>

						<div class="gg_coll_gall_cats">
							<span>'. $gall_cats .'</span>
						</div>
					</td>
					<td class="gg_coll_gall_inner" style="vertical-align: top;">
						<div>
							<h2>
								<a href="'.get_admin_url().'post.php?post='.$gid.'&action=edit" target="_blank" title="'. __('edit gallery', GG_ML).'">'.get_the_title($gid).'</a>
							</h2>
							<br/>
							
							<div style="width: 16%; margin-right: 4%;">
								<p>'.__('Random display?', GG_ML).'</p>
								<input type="checkbox" name="random" class="ip-checkbox" value="1" '.$rand_check.' />
							</div>
							<div style="width: 16%; margin-right: 4%;">
								<p>'.__('Use tags filter?', GG_ML).'</p>
								<input type="checkbox" name="tags_filter" class="ip-checkbox" value="1" '.$filter_check.' />
							</div>
							<div style="width: 16%; margin-right: 4%;">
								<p>'.__('Search Box?', GG_ML).'</p>
								<input type="checkbox" name="search" class="ip-checkbox" value="1" '.$search_check.' />
							</div>
							<div style="width: 16%; margin-right: 4%;">
								<p>'.__('Use watermark?', GG_ML).'</p>
								<input type="checkbox" name="watermark" class="ip-checkbox" value="1" '.$wmark_check.' />
							</div>
							<div style="width: 16%;">
								<p>'.__('Image link', GG_ML).'</p>
								<select name="gg_linking_dd" class="gg_linking_dd">
									<option value="none">'. __('No link', GG_ML) .'</option>
									<option value="page" '; if($link_subj == 'page') {echo 'selected="selected"';} echo '>'. __('To a page', GG_ML) .'</option>
									<option value="custom" '; if($link_subj == 'custom') {echo 'selected="selected"';} echo '>'. __('Custom link', GG_ML) .'</option>
								</select>
								<div class="gg_link_wrap">'. gg_link_field($link_subj, $link_val) .'</div>
							</div>
							
							<div>
								<textarea name="coll_descr" class="coll_descr" placeholder="'. esc_attr(__('Gallery description - supports %IMG-NUM% placeholder', GG_ML)) .'">'.$descr.'</textarea>
							</div>	
							
						</div>
					</td>
				  </tr>
				  ';
			  }
			  $a++;
            }
          }
		  else {echo '<tr><td colspan="5"><p>'.__('No selected galleries', GG_ML).' ..</p></td></tr>';}
          ?>
		  </tbody>
       </table>
       </div> 
         
	</div>
    </div>
    </div>
	<?php
	die();
}
add_action('wp_ajax_gg_coll_builder', 'gg_coll_builder');




////////////////////////////////////////////////
////// GET GALLERIES FOR A CATEGORY ////////////
////////////////////////////////////////////////

function gg_cat_galleries_code($fnc_cat = false) {	
	$cat = $fnc_cat;
	$code = '';
	
	// if is not called directly
	if(!$cat) {
		if(!isset($_POST['gallery_cat'])) {die('missing data');}
		$cat = $_POST['gallery_cat'];
	}

	$post_list = gg_cat_galleries($cat);	
	if(!$post_list) {return false;}
	
	foreach($post_list as $post) {
		$code .= '
		<li style="background-image: url('.gg_thumb_src($post['img'], 200, 170, 70).');" rel="'.$post['id'].'" title="'. __('add to collection', GG_ML) .'" gg-cats="'.$post['cats'].'" gg-img="'.gg_thumb_src($post['img'], 500, 500, 70).'">
			<div title="'.$post['title'].'">'.$post['title'].'</div>
		</li>';
	}

	
	if($fnc_cat == false) {die( $code );}
	else {return $code;}
}
add_action('wp_ajax_gg_cat_galleries_code', 'gg_cat_galleries_code');



////////////////////////////////////////////
////// SAVE COLLECTION CONTENTS ////////////
////////////////////////////////////////////

function gg_save_coll() {	
	if(!isset($_POST['coll_id'])) {die('missing data');}
	$coll_id = (int)$_POST['coll_id'];
	
	$data = array();
	$to_check = array('gall_list', 'cust_img', 'random_flag', 'filters_flag', 'search_flag', 'wmark_flag', 'link_subj', 'link_val', 'coll_descr');
	foreach($to_check as $tc) {
		$data[$tc] = (!isset($_POST[$tc])) ? '' : $_POST[$tc];	
	}
	
	// create the categories array
	$terms_array = array();
	if(is_array($data['gall_list'])) {
		foreach($data['gall_list'] as $post_id) {
			$pid_terms = wp_get_post_terms($post_id, 'gg_gall_categories', array("fields" => "ids"));
			
			foreach($pid_terms as $pid_term) { 
				$terms_array[] = $pid_term;
			}	
		}
		$terms_array = array_unique($terms_array);
	}
	
	// create the galleries array
	$galleries = array();
	if(is_array($data['gall_list'])) {
		$a = 0;
		foreach($data['gall_list'] as $gid) {
			$galleries[] = array(
				'id' 		=> $gid,
				'cust_img'	=> $data['cust_img'][$a],
				'rand'		=> $data['random_flag'][$a],
				'filters'	=> $data['filters_flag'][$a],
				'search'	=> $data['search_flag'][$a],
				'wmark' 	=> $data['wmark_flag'][$a],
				'link_subj' => $data['link_subj'][$a],
				'link_val' 	=> gg_sanitize_input(stripslashes($data['link_val'][$a])),
				'descr'		=> gg_sanitize_input(stripslashes($data['descr'][$a])) 
			);	
			$a++;
		}
	}

	// final array
	$coll_arr = array(
		'galleries' => $galleries,
		'categories' => $terms_array
	);
	
	// update the collection term
	$result = wp_update_term($coll_id, 'gg_collections', array(
	  'slug' => uniqid(),
	  'description' => serialize($coll_arr)
	));
	
	
	if(is_wp_error($result)) {echo 'error';}
	else {echo 'success';}	

	die();
}
add_action('wp_ajax_gg_save_coll', 'gg_save_coll');

